Learn R Programming

powRICLPM (version 0.2.0)

powRICLPM-package: powRICLPM: Perform Power Analysis for the RI-CLPM and STARTS Model

Description

Perform user-friendly power analyses for the random intercept cross-lagged panel model (RI-CLPM) and the bivariate stable trait autoregressive trait state (STARTS) model. The strategy as proposed by Mulder (2023) tools:::Rd_expr_doi("10.1080/10705511.2022.2122467") is implemented. Extensions include the use of parameter constraints over time, bounded estimation, generation of data with skewness and kurtosis, and the option to setup the power analysis for Mplus.

Arguments

Author

Maintainer: Jeroen Mulder j.d.mulder@uu.nl (ORCID) [copyright holder]

Other contributors:

  • Netherlands Organization for Scientific Research [funder]

See Also