Learn R Programming

powRICLPM (version 0.2.0)

check_Phi: Check Interpretation Phi Argument

Description

Write a textual interpretation of the values in Phi. This can be used to check if Phi has been correctly specified.

Usage

check_Phi(Phi)

Value

No return value, called for side effects.

Arguments

Phi

A matrix, with standardized autoregressive effects (on the diagonal) and cross-lagged effects (off-diagonal) in the population. Columns represent predictors and rows represent outcomes.

Examples

Run this code
# Correctly specified `Phi`
Phi1 <- matrix(c(.4, .1, .2, .3), ncol = 2, byrow = TRUE)
check_Phi(Phi1)

# `Phi` with too large standardized effects
Phi2 <- matrix(c(.6, .5, .4, .7), ncol = 2, byrow = TRUE)
Phi2 <- check_Phi(Phi2)

Run the code above in your browser using DataLab