Learn R Programming

powRICLPM (version 0.1.1)

print.powRICLPM: Print powRICLPM object

Description

print.powRICLPM prints a table listing all experimental conditions contained in the powRICLPM object, as well as the frequency of the estimation problems that occurred in each.

Usage

# S3 method for powRICLPM
print(x, ...)

Value

No return value, called for side effects.

Arguments

x

A powRICLPM object.

...

Argument not in use.