Learn R Programming

powRICLPM (version 0.2.0)

summary.powRICLPM: Summarize Results from powRICLPM Object

Description

S3 method for class powRICLPM. summary.powRICLPM summarizes the setup and results of the powRICLPM analysis. Depending on the arguments that are set, summary.powRICLPM provides a different summary (see "Details").

Usage

# S3 method for powRICLPM
summary(
  object,
  ...,
  parameter = NULL,
  sample_size = NULL,
  time_points = NULL,
  ICC = NULL,
  reliability = NULL
)

Value

No return value, called for side effects.

Arguments

object

A powRICLPM object.

...

(don't use)

parameter

Character string of length 1 denoting the parameter to visualize the results for.

sample_size

(optional) An integer, denoting the sample size of the experimental condition of interest.

time_points

(optional) An integer, denoting the number of time points of the experimental condition of interest.

ICC

(optional) A double, denoting the proportion of variance at the between-unit level of the experimental condition of interest.

reliability

(optional) An integer, denoting the reliability of the indicators of the experimental condition of interest.

Details

summary.powRICLPM provides a different summary of the powRICLPM object, depending on the additional arguments that are set:

  • When sample_size = ..., time_points = ..., ICC = ..., and reliability are set: Estimation information and results for all parameters across experimental conditions.

  • When parameter = "..." is set: Estimation information and results for a specific parameter across all experimental conditions.

  • No additional arguments: Characteristics of the different experimental conditions are summarized, as well as session info (information that applies to all conditions, such the number of replications, etc.).

Examples

Run this code
# \dontshow{
load(system.file("extdata", "out_preliminary.RData", package = "powRICLPM"))
# }

# Get setup of powRICLPM analysis and convergence issues
summary(out_preliminary)

# Performance measures for "wB2~wA1" parameter across experimental conditions
summary(out_preliminary, parameter = "wB2~wA1")

# Performance measures for all parameters, for specific experimental condition
summary(out_preliminary, sample_size = 700, time_points = 4, ICC = .3, reliability = 1)

Run the code above in your browser using DataLab